==> react-atom-input-5.4.0.tgz: package/lib/Password/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["onChange", "pwShowLabel", "pwHideLabel"];
import { useState } from 'react';
import PropTypes from 'prop-types';
import Input from '../Input';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var BASE_CLASS = 'sui-AtomInput';
var CLASS_PASSWORD = BASE_CLASS + "-password";
var CLASS_PASSWORD_TOGGLE_BUTTON = CLASS_PASSWORD + "--toggleButton";
var TEXT = 'text';
var PASSWORD = 'password';
var HIDE_LABEL = 'hide';
var SHOW_LABEL = 'show';

var Password = function Password(_ref) {
  var onChange = _ref.onChange,
      pwShowLabel = _ref.pwShowLabel,
      pwHideLabel = _ref.pwHideLabel,
      props = _objectWithoutPropertiesLoose(_ref, _excluded);

  var _useState = useState(PASSWORD),
      type = _useState[0],
      setType = _useState[1];

  var _useState2 = useState(''),
      value = _useState2[0],
      setValue = _useState2[1];

  var toggle = function toggle() {
    var inputType = type === PASSWORD ? TEXT : PASSWORD;
    setType(inputType);
  };

  var handleChange = function handleChange(ev, _ref2) {
    var value = _ref2.value;
    setValue(value);
    onChange(ev, {
      value: value
    });
  };

  return /*#__PURE__*/_jsxs("div", {
    className: CLASS_PASSWORD,
    children: [/*#__PURE__*/_jsx(Input, _extends({}, props, {
      onChange: handleChange,
      value: value,
      type: type
    })), /*#__PURE__*/_jsx("div", {
      onClick: toggle,
      className: CLASS_PASSWORD_TOGGLE_BUTTON,
      children: type === PASSWORD ? pwShowLabel : pwHideLabel
    })]
  });
};

Password.defaultProps = {
  pwShowLabel: SHOW_LABEL,
  pwHideLabel: HIDE_LABEL,
  onChange: function onChange() {}
};
export default Password;

==> react-atom-input-5.12.0.tgz: package/lib/Password/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["onChange", "pwShowLabel", "pwHideLabel"];
import { useState } from 'react';
import PropTypes from 'prop-types';
import Input from '../Input';
import { BASE_CLASS_PASSWORD, BASE_CLASS_PASSWORD_TOGGLE_BUTTON, TEXT, PASSWORD } from './config';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var Password = function Password(_ref) {
  var onChange = _ref.onChange,
      _ref$pwShowLabel = _ref.pwShowLabel,
      pwShowLabel = _ref$pwShowLabel === void 0 ? 'show' : _ref$pwShowLabel,
      _ref$pwHideLabel = _ref.pwHideLabel,
      pwHideLabel = _ref$pwHideLabel === void 0 ? 'hide' : _ref$pwHideLabel,
      props = _objectWithoutPropertiesLoose(_ref, _excluded);

  var _useState = useState(PASSWORD),
      type = _useState[0],
      setType = _useState[1];

  var _useState2 = useState(''),
      value = _useState2[0],
      setValue = _useState2[1];

  var toggle = function toggle() {
    var inputType = type === PASSWORD ? TEXT : PASSWORD;
    setType(inputType);
  };

  var handleChange = function handleChange(ev, _ref2) {
    var value = _ref2.value;
    setValue(value);
    typeof onChange === 'function' && onChange(ev, {
      value: value
    });
  };

  return /*#__PURE__*/_jsxs("div", {
    className: BASE_CLASS_PASSWORD,
    children: [/*#__PURE__*/_jsx(Input, _extends({}, props, {
      onChange: handleChange,
      value: value,
      type: type
    })), /*#__PURE__*/_jsx("div", {
      onClick: toggle,
      className: BASE_CLASS_PASSWORD_TOGGLE_BUTTON,
      children: type === PASSWORD ? pwShowLabel : pwHideLabel
    })]
  });
};

export default Password;
